get_facts_scenarios: List the names of simulation scenarios
Description
Get the names of the simulation scenarios of a FACTS file.
without actually running any simulations.
These names usually come from the virtual subject response (VSR)
scenarios, the accrual profiles, and the dropout profiles.
Usage
get_facts_scenarios(facts_file, verbose = FALSE)
Value
Character vector of FACTS simulation scenarios.
Arguments
facts_file
Character, name of a FACTS file.
Usually has a *.facts file extension.
verbose
Logical, whether to print progress to the R console.
# Can only run if system dependencies are configured:if (file.exists(Sys.getenv("RFACTS_PATHS"))) {
facts_file <- get_facts_file_example("contin.facts")
get_facts_scenarios(facts_file)
}