Learn R Programming

rfacts (version 0.2.1)

get_facts_versions: List supported FACTS versions

Description

List versions of FACTS supported by rfacts. You can supply any of these versions to functions engine-specific functions such as run_engine_contin().

Usage

get_facts_versions()

Arguments

Value

A character vector of supported FACTS versions.

Details

If your FACTS file does not perfectly agree with one of the supported versions, rfacts will try to find the best version for you, either

  1. The greatest supported version less than or equal to the one in the FACTS file, or

  2. The lowest supported version if (1) does not exist.

See Also

get_facts_version(), run_engine_contin()

Examples

Run this code
# Can only run if system dependencies are configured:
if (file.exists(Sys.getenv("RFACTS_PATHS"))) {
get_facts_versions()
}

Run the code above in your browser using DataLab