powered by
List versions of FACTS supported by rfacts. You can supply any of these versions to functions engine-specific functions such as run_engine_contin().
rfacts
run_engine_contin()
get_facts_versions()
A character vector of supported FACTS versions.
If your FACTS file does not perfectly agree with one of the supported versions, rfacts will try to find the best version for you, either
The greatest supported version less than or equal to the one in the FACTS file, or
The lowest supported version if (1) does not exist.
get_facts_version(), run_engine_contin()
get_facts_version()
# Can only run if system dependencies are configured: if (file.exists(Sys.getenv("RFACTS_PATHS"))) { get_facts_versions() }
Run the code above in your browser using DataLab