A FACTS file has a special kind of XML format.
Most of the content sits in an overarching <facts> tag,
then a <parameterSets> tag, then a
<parameterSet> tag, then a <property> tag.
For example, here is the part of a FACTS file that controls
the weeks between interims.
<facts>
<parameterSets type="NucleusParameterSet">
<parameterSet name="nucleus">
<property name="update_freq_save">4</property>
To use the read_facts() function, you must first identify
the parts of the FACTS file you want to read using the fields argument.
To read the above part of the XML, you would first define the
update_freq_save field.
fields <- tibble::tibble(
field = "my_interval",
type = "NucleusParameterSet",
set = "nucleus",
property = "update_freq_save"
)
and then call read_facts(input = "your_file.facts", fields = fields).