- facts_file
Character, name of a FACTS file.
Usually has a *.facts file extension.
- output_path
Character, directory path to the files to generate.
- log_path
Character, path to the log file generated by FLFLL.
- n_burn
Number of burn-in iterations for the MCMC.
- n_mcmc
Number of MCMC iterations used in inference.
- n_weeks_files
Number of weeks*.csv files to save in output_path.
- n_patients_files
Number of patients*.csv files to save in
output_path.
- n_mcmc_files
Number of mcmc*.csv files to save in
output_path.
- n_mcmc_thin
Number of thinning iterations for the MCMC.
- flfll_seed
Positive integer, random number generator seed for FLFLL.
This seed is only used for stochastic preprocessing steps for generating
the *.param files. It is not the random number generator seed
for the actual trial simulations. To set the trial simulation seed,
use the seed argument of run_facts(), run_engine(), or
one of the specific run_engine*() functions.
- flfll_offset
Integer, offset for the random number generator.
- verbose
Logical, whether to print progress information to the
R console.
- max_sims
Positive integer of length 1, maximum number of simulations
that will be allowed to run for certain engines like CRM
in subsequent calls to the engine. If the n_sims argument
of the engine is larger than max_sims, only max_sims
simulations will be run. The max_sims argument
only applies to FLFLL >= 6.4.1
and only needs to be set manually if you are manually calling
run_flfll() and then the engine instead of just run_facts().